"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6398 import AbstractAssemblyCompoundCriticalSpeedAnalysis
    from ._6399 import AbstractShaftCompoundCriticalSpeedAnalysis
    from ._6400 import AbstractShaftOrHousingCompoundCriticalSpeedAnalysis
    from ._6401 import AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6402 import AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis
    from ._6403 import AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6404 import AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6405 import AssemblyCompoundCriticalSpeedAnalysis
    from ._6406 import BearingCompoundCriticalSpeedAnalysis
    from ._6407 import BeltConnectionCompoundCriticalSpeedAnalysis
    from ._6408 import BeltDriveCompoundCriticalSpeedAnalysis
    from ._6409 import BevelDifferentialGearCompoundCriticalSpeedAnalysis
    from ._6410 import BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis
    from ._6411 import BevelDifferentialGearSetCompoundCriticalSpeedAnalysis
    from ._6412 import BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis
    from ._6413 import BevelDifferentialSunGearCompoundCriticalSpeedAnalysis
    from ._6414 import BevelGearCompoundCriticalSpeedAnalysis
    from ._6415 import BevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6416 import BevelGearSetCompoundCriticalSpeedAnalysis
    from ._6417 import BoltCompoundCriticalSpeedAnalysis
    from ._6418 import BoltedJointCompoundCriticalSpeedAnalysis
    from ._6419 import ClutchCompoundCriticalSpeedAnalysis
    from ._6420 import ClutchConnectionCompoundCriticalSpeedAnalysis
    from ._6421 import ClutchHalfCompoundCriticalSpeedAnalysis
    from ._6422 import CoaxialConnectionCompoundCriticalSpeedAnalysis
    from ._6423 import ComponentCompoundCriticalSpeedAnalysis
    from ._6424 import ConceptCouplingCompoundCriticalSpeedAnalysis
    from ._6425 import ConceptCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6426 import ConceptCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6427 import ConceptGearCompoundCriticalSpeedAnalysis
    from ._6428 import ConceptGearMeshCompoundCriticalSpeedAnalysis
    from ._6429 import ConceptGearSetCompoundCriticalSpeedAnalysis
    from ._6430 import ConicalGearCompoundCriticalSpeedAnalysis
    from ._6431 import ConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6432 import ConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6433 import ConnectionCompoundCriticalSpeedAnalysis
    from ._6434 import ConnectorCompoundCriticalSpeedAnalysis
    from ._6435 import CouplingCompoundCriticalSpeedAnalysis
    from ._6436 import CouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6437 import CouplingHalfCompoundCriticalSpeedAnalysis
    from ._6438 import CVTBeltConnectionCompoundCriticalSpeedAnalysis
    from ._6439 import CVTCompoundCriticalSpeedAnalysis
    from ._6440 import CVTPulleyCompoundCriticalSpeedAnalysis
    from ._6441 import CycloidalAssemblyCompoundCriticalSpeedAnalysis
    from ._6442 import CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6443 import CycloidalDiscCompoundCriticalSpeedAnalysis
    from ._6444 import CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6445 import CylindricalGearCompoundCriticalSpeedAnalysis
    from ._6446 import CylindricalGearMeshCompoundCriticalSpeedAnalysis
    from ._6447 import CylindricalGearSetCompoundCriticalSpeedAnalysis
    from ._6448 import CylindricalPlanetGearCompoundCriticalSpeedAnalysis
    from ._6449 import DatumCompoundCriticalSpeedAnalysis
    from ._6450 import ExternalCADModelCompoundCriticalSpeedAnalysis
    from ._6451 import FaceGearCompoundCriticalSpeedAnalysis
    from ._6452 import FaceGearMeshCompoundCriticalSpeedAnalysis
    from ._6453 import FaceGearSetCompoundCriticalSpeedAnalysis
    from ._6454 import FEPartCompoundCriticalSpeedAnalysis
    from ._6455 import FlexiblePinAssemblyCompoundCriticalSpeedAnalysis
    from ._6456 import GearCompoundCriticalSpeedAnalysis
    from ._6457 import GearMeshCompoundCriticalSpeedAnalysis
    from ._6458 import GearSetCompoundCriticalSpeedAnalysis
    from ._6459 import GuideDxfModelCompoundCriticalSpeedAnalysis
    from ._6460 import HypoidGearCompoundCriticalSpeedAnalysis
    from ._6461 import HypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6462 import HypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6463 import InterMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6464 import KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis
    from ._6465 import KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6466 import KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6467 import KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis
    from ._6468 import KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6469 import KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6470 import KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6471 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6472 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6473 import MassDiscCompoundCriticalSpeedAnalysis
    from ._6474 import MeasurementComponentCompoundCriticalSpeedAnalysis
    from ._6475 import MountableComponentCompoundCriticalSpeedAnalysis
    from ._6476 import OilSealCompoundCriticalSpeedAnalysis
    from ._6477 import PartCompoundCriticalSpeedAnalysis
    from ._6478 import PartToPartShearCouplingCompoundCriticalSpeedAnalysis
    from ._6479 import PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6480 import PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6481 import PlanetaryConnectionCompoundCriticalSpeedAnalysis
    from ._6482 import PlanetaryGearSetCompoundCriticalSpeedAnalysis
    from ._6483 import PlanetCarrierCompoundCriticalSpeedAnalysis
    from ._6484 import PointLoadCompoundCriticalSpeedAnalysis
    from ._6485 import PowerLoadCompoundCriticalSpeedAnalysis
    from ._6486 import PulleyCompoundCriticalSpeedAnalysis
    from ._6487 import RingPinsCompoundCriticalSpeedAnalysis
    from ._6488 import RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis
    from ._6489 import RollingRingAssemblyCompoundCriticalSpeedAnalysis
    from ._6490 import RollingRingCompoundCriticalSpeedAnalysis
    from ._6491 import RollingRingConnectionCompoundCriticalSpeedAnalysis
    from ._6492 import RootAssemblyCompoundCriticalSpeedAnalysis
    from ._6493 import ShaftCompoundCriticalSpeedAnalysis
    from ._6494 import ShaftHubConnectionCompoundCriticalSpeedAnalysis
    from ._6495 import ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6496 import SpecialisedAssemblyCompoundCriticalSpeedAnalysis
    from ._6497 import SpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6498 import SpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6499 import SpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6500 import SpringDamperCompoundCriticalSpeedAnalysis
    from ._6501 import SpringDamperConnectionCompoundCriticalSpeedAnalysis
    from ._6502 import SpringDamperHalfCompoundCriticalSpeedAnalysis
    from ._6503 import StraightBevelDiffGearCompoundCriticalSpeedAnalysis
    from ._6504 import StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis
    from ._6505 import StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis
    from ._6506 import StraightBevelGearCompoundCriticalSpeedAnalysis
    from ._6507 import StraightBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6508 import StraightBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6509 import StraightBevelPlanetGearCompoundCriticalSpeedAnalysis
    from ._6510 import StraightBevelSunGearCompoundCriticalSpeedAnalysis
    from ._6511 import SynchroniserCompoundCriticalSpeedAnalysis
    from ._6512 import SynchroniserHalfCompoundCriticalSpeedAnalysis
    from ._6513 import SynchroniserPartCompoundCriticalSpeedAnalysis
    from ._6514 import SynchroniserSleeveCompoundCriticalSpeedAnalysis
    from ._6515 import TorqueConverterCompoundCriticalSpeedAnalysis
    from ._6516 import TorqueConverterConnectionCompoundCriticalSpeedAnalysis
    from ._6517 import TorqueConverterPumpCompoundCriticalSpeedAnalysis
    from ._6518 import TorqueConverterTurbineCompoundCriticalSpeedAnalysis
    from ._6519 import UnbalancedMassCompoundCriticalSpeedAnalysis
    from ._6520 import VirtualComponentCompoundCriticalSpeedAnalysis
    from ._6521 import WormGearCompoundCriticalSpeedAnalysis
    from ._6522 import WormGearMeshCompoundCriticalSpeedAnalysis
    from ._6523 import WormGearSetCompoundCriticalSpeedAnalysis
    from ._6524 import ZerolBevelGearCompoundCriticalSpeedAnalysis
    from ._6525 import ZerolBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6526 import ZerolBevelGearSetCompoundCriticalSpeedAnalysis
