"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3507 import AbstractAssemblyStabilityAnalysis
    from ._3508 import AbstractShaftOrHousingStabilityAnalysis
    from ._3509 import AbstractShaftStabilityAnalysis
    from ._3510 import AbstractShaftToMountableComponentConnectionStabilityAnalysis
    from ._3511 import AGMAGleasonConicalGearMeshStabilityAnalysis
    from ._3512 import AGMAGleasonConicalGearSetStabilityAnalysis
    from ._3513 import AGMAGleasonConicalGearStabilityAnalysis
    from ._3514 import AssemblyStabilityAnalysis
    from ._3515 import BearingStabilityAnalysis
    from ._3516 import BeltConnectionStabilityAnalysis
    from ._3517 import BeltDriveStabilityAnalysis
    from ._3518 import BevelDifferentialGearMeshStabilityAnalysis
    from ._3519 import BevelDifferentialGearSetStabilityAnalysis
    from ._3520 import BevelDifferentialGearStabilityAnalysis
    from ._3521 import BevelDifferentialPlanetGearStabilityAnalysis
    from ._3522 import BevelDifferentialSunGearStabilityAnalysis
    from ._3523 import BevelGearMeshStabilityAnalysis
    from ._3524 import BevelGearSetStabilityAnalysis
    from ._3525 import BevelGearStabilityAnalysis
    from ._3526 import BoltedJointStabilityAnalysis
    from ._3527 import BoltStabilityAnalysis
    from ._3528 import ClutchConnectionStabilityAnalysis
    from ._3529 import ClutchHalfStabilityAnalysis
    from ._3530 import ClutchStabilityAnalysis
    from ._3531 import CoaxialConnectionStabilityAnalysis
    from ._3532 import ComponentStabilityAnalysis
    from ._3533 import ConceptCouplingConnectionStabilityAnalysis
    from ._3534 import ConceptCouplingHalfStabilityAnalysis
    from ._3535 import ConceptCouplingStabilityAnalysis
    from ._3536 import ConceptGearMeshStabilityAnalysis
    from ._3537 import ConceptGearSetStabilityAnalysis
    from ._3538 import ConceptGearStabilityAnalysis
    from ._3539 import ConicalGearMeshStabilityAnalysis
    from ._3540 import ConicalGearSetStabilityAnalysis
    from ._3541 import ConicalGearStabilityAnalysis
    from ._3542 import ConnectionStabilityAnalysis
    from ._3543 import ConnectorStabilityAnalysis
    from ._3544 import CouplingConnectionStabilityAnalysis
    from ._3545 import CouplingHalfStabilityAnalysis
    from ._3546 import CouplingStabilityAnalysis
    from ._3547 import CriticalSpeed
    from ._3548 import CVTBeltConnectionStabilityAnalysis
    from ._3549 import CVTPulleyStabilityAnalysis
    from ._3550 import CVTStabilityAnalysis
    from ._3551 import CycloidalAssemblyStabilityAnalysis
    from ._3552 import CycloidalDiscCentralBearingConnectionStabilityAnalysis
    from ._3553 import CycloidalDiscPlanetaryBearingConnectionStabilityAnalysis
    from ._3554 import CycloidalDiscStabilityAnalysis
    from ._3555 import CylindricalGearMeshStabilityAnalysis
    from ._3556 import CylindricalGearSetStabilityAnalysis
    from ._3557 import CylindricalGearStabilityAnalysis
    from ._3558 import CylindricalPlanetGearStabilityAnalysis
    from ._3559 import DatumStabilityAnalysis
    from ._2379 import DynamicModelForStabilityAnalysis
    from ._3560 import ExternalCADModelStabilityAnalysis
    from ._3561 import FaceGearMeshStabilityAnalysis
    from ._3562 import FaceGearSetStabilityAnalysis
    from ._3563 import FaceGearStabilityAnalysis
    from ._3564 import FEPartStabilityAnalysis
    from ._3565 import FlexiblePinAssemblyStabilityAnalysis
    from ._3566 import GearMeshStabilityAnalysis
    from ._3567 import GearSetStabilityAnalysis
    from ._3568 import GearStabilityAnalysis
    from ._3569 import GuideDxfModelStabilityAnalysis
    from ._3570 import HypoidGearMeshStabilityAnalysis
    from ._3571 import HypoidGearSetStabilityAnalysis
    from ._3572 import HypoidGearStabilityAnalysis
    from ._3573 import InterMountableComponentConnectionStabilityAnalysis
    from ._3574 import KlingelnbergCycloPalloidConicalGearMeshStabilityAnalysis
    from ._3575 import KlingelnbergCycloPalloidConicalGearSetStabilityAnalysis
    from ._3576 import KlingelnbergCycloPalloidConicalGearStabilityAnalysis
    from ._3577 import KlingelnbergCycloPalloidHypoidGearMeshStabilityAnalysis
    from ._3578 import KlingelnbergCycloPalloidHypoidGearSetStabilityAnalysis
    from ._3579 import KlingelnbergCycloPalloidHypoidGearStabilityAnalysis
    from ._3580 import KlingelnbergCycloPalloidSpiralBevelGearMeshStabilityAnalysis
    from ._3581 import KlingelnbergCycloPalloidSpiralBevelGearSetStabilityAnalysis
    from ._3582 import KlingelnbergCycloPalloidSpiralBevelGearStabilityAnalysis
    from ._3583 import MassDiscStabilityAnalysis
    from ._3584 import MeasurementComponentStabilityAnalysis
    from ._3585 import MountableComponentStabilityAnalysis
    from ._3586 import OilSealStabilityAnalysis
    from ._3587 import PartStabilityAnalysis
    from ._3588 import PartToPartShearCouplingConnectionStabilityAnalysis
    from ._3589 import PartToPartShearCouplingHalfStabilityAnalysis
    from ._3590 import PartToPartShearCouplingStabilityAnalysis
    from ._3591 import PlanetaryConnectionStabilityAnalysis
    from ._3592 import PlanetaryGearSetStabilityAnalysis
    from ._3593 import PlanetCarrierStabilityAnalysis
    from ._3594 import PointLoadStabilityAnalysis
    from ._3595 import PowerLoadStabilityAnalysis
    from ._3596 import PulleyStabilityAnalysis
    from ._3597 import RingPinsStabilityAnalysis
    from ._3598 import RingPinsToDiscConnectionStabilityAnalysis
    from ._3599 import RollingRingAssemblyStabilityAnalysis
    from ._3600 import RollingRingConnectionStabilityAnalysis
    from ._3601 import RollingRingStabilityAnalysis
    from ._3602 import RootAssemblyStabilityAnalysis
    from ._3603 import ShaftHubConnectionStabilityAnalysis
    from ._3604 import ShaftStabilityAnalysis
    from ._3605 import ShaftToMountableComponentConnectionStabilityAnalysis
    from ._3606 import SpecialisedAssemblyStabilityAnalysis
    from ._3607 import SpiralBevelGearMeshStabilityAnalysis
    from ._3608 import SpiralBevelGearSetStabilityAnalysis
    from ._3609 import SpiralBevelGearStabilityAnalysis
    from ._3610 import SpringDamperConnectionStabilityAnalysis
    from ._3611 import SpringDamperHalfStabilityAnalysis
    from ._3612 import SpringDamperStabilityAnalysis
    from ._2391 import StabilityAnalysis
    from ._3613 import StabilityAnalysisDrawStyle
    from ._3614 import StabilityAnalysisOptions
    from ._3615 import StraightBevelDiffGearMeshStabilityAnalysis
    from ._3616 import StraightBevelDiffGearSetStabilityAnalysis
    from ._3617 import StraightBevelDiffGearStabilityAnalysis
    from ._3618 import StraightBevelGearMeshStabilityAnalysis
    from ._3619 import StraightBevelGearSetStabilityAnalysis
    from ._3620 import StraightBevelGearStabilityAnalysis
    from ._3621 import StraightBevelPlanetGearStabilityAnalysis
    from ._3622 import StraightBevelSunGearStabilityAnalysis
    from ._3623 import SynchroniserHalfStabilityAnalysis
    from ._3624 import SynchroniserPartStabilityAnalysis
    from ._3625 import SynchroniserSleeveStabilityAnalysis
    from ._3626 import SynchroniserStabilityAnalysis
    from ._3627 import TorqueConverterConnectionStabilityAnalysis
    from ._3628 import TorqueConverterPumpStabilityAnalysis
    from ._3629 import TorqueConverterStabilityAnalysis
    from ._3630 import TorqueConverterTurbineStabilityAnalysis
    from ._3631 import UnbalancedMassStabilityAnalysis
    from ._3632 import VirtualComponentStabilityAnalysis
    from ._3633 import WormGearMeshStabilityAnalysis
    from ._3634 import WormGearSetStabilityAnalysis
    from ._3635 import WormGearStabilityAnalysis
    from ._3636 import ZerolBevelGearMeshStabilityAnalysis
    from ._3637 import ZerolBevelGearSetStabilityAnalysis
    from ._3638 import ZerolBevelGearStabilityAnalysis
