"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2595 import AbstractAssemblyCompoundSystemDeflection
    from ._2596 import AbstractShaftCompoundSystemDeflection
    from ._2597 import AbstractShaftOrHousingCompoundSystemDeflection
    from ._2598 import AbstractShaftToMountableComponentConnectionCompoundSystemDeflection
    from ._2599 import AGMAGleasonConicalGearCompoundSystemDeflection
    from ._2600 import AGMAGleasonConicalGearMeshCompoundSystemDeflection
    from ._2601 import AGMAGleasonConicalGearSetCompoundSystemDeflection
    from ._2602 import AssemblyCompoundSystemDeflection
    from ._2603 import BearingCompoundSystemDeflection
    from ._2604 import BeltConnectionCompoundSystemDeflection
    from ._2605 import BeltDriveCompoundSystemDeflection
    from ._2606 import BevelDifferentialGearCompoundSystemDeflection
    from ._2607 import BevelDifferentialGearMeshCompoundSystemDeflection
    from ._2608 import BevelDifferentialGearSetCompoundSystemDeflection
    from ._2609 import BevelDifferentialPlanetGearCompoundSystemDeflection
    from ._2610 import BevelDifferentialSunGearCompoundSystemDeflection
    from ._2611 import BevelGearCompoundSystemDeflection
    from ._2612 import BevelGearMeshCompoundSystemDeflection
    from ._2613 import BevelGearSetCompoundSystemDeflection
    from ._2614 import BoltCompoundSystemDeflection
    from ._2615 import BoltedJointCompoundSystemDeflection
    from ._2616 import ClutchCompoundSystemDeflection
    from ._2617 import ClutchConnectionCompoundSystemDeflection
    from ._2618 import ClutchHalfCompoundSystemDeflection
    from ._2619 import CoaxialConnectionCompoundSystemDeflection
    from ._2620 import ComponentCompoundSystemDeflection
    from ._2621 import ConceptCouplingCompoundSystemDeflection
    from ._2622 import ConceptCouplingConnectionCompoundSystemDeflection
    from ._2623 import ConceptCouplingHalfCompoundSystemDeflection
    from ._2624 import ConceptGearCompoundSystemDeflection
    from ._2625 import ConceptGearMeshCompoundSystemDeflection
    from ._2626 import ConceptGearSetCompoundSystemDeflection
    from ._2627 import ConicalGearCompoundSystemDeflection
    from ._2628 import ConicalGearMeshCompoundSystemDeflection
    from ._2629 import ConicalGearSetCompoundSystemDeflection
    from ._2630 import ConnectionCompoundSystemDeflection
    from ._2631 import ConnectorCompoundSystemDeflection
    from ._2632 import CouplingCompoundSystemDeflection
    from ._2633 import CouplingConnectionCompoundSystemDeflection
    from ._2634 import CouplingHalfCompoundSystemDeflection
    from ._2635 import CVTBeltConnectionCompoundSystemDeflection
    from ._2636 import CVTCompoundSystemDeflection
    from ._2637 import CVTPulleyCompoundSystemDeflection
    from ._2638 import CycloidalAssemblyCompoundSystemDeflection
    from ._2639 import CycloidalDiscCentralBearingConnectionCompoundSystemDeflection
    from ._2640 import CycloidalDiscCompoundSystemDeflection
    from ._2641 import CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection
    from ._2642 import CylindricalGearCompoundSystemDeflection
    from ._2643 import CylindricalGearMeshCompoundSystemDeflection
    from ._2644 import CylindricalGearSetCompoundSystemDeflection
    from ._2645 import CylindricalPlanetGearCompoundSystemDeflection
    from ._2646 import DatumCompoundSystemDeflection
    from ._2647 import DutyCycleEfficiencyResults
    from ._2648 import ExternalCADModelCompoundSystemDeflection
    from ._2649 import FaceGearCompoundSystemDeflection
    from ._2650 import FaceGearMeshCompoundSystemDeflection
    from ._2651 import FaceGearSetCompoundSystemDeflection
    from ._2652 import FEPartCompoundSystemDeflection
    from ._2653 import FlexiblePinAssemblyCompoundSystemDeflection
    from ._2654 import GearCompoundSystemDeflection
    from ._2655 import GearMeshCompoundSystemDeflection
    from ._2656 import GearSetCompoundSystemDeflection
    from ._2657 import GuideDxfModelCompoundSystemDeflection
    from ._2658 import HypoidGearCompoundSystemDeflection
    from ._2659 import HypoidGearMeshCompoundSystemDeflection
    from ._2660 import HypoidGearSetCompoundSystemDeflection
    from ._2661 import InterMountableComponentConnectionCompoundSystemDeflection
    from ._2662 import KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection
    from ._2663 import KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection
    from ._2664 import KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection
    from ._2665 import KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection
    from ._2666 import KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection
    from ._2667 import KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection
    from ._2668 import KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection
    from ._2669 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection
    from ._2670 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection
    from ._2671 import MassDiscCompoundSystemDeflection
    from ._2672 import MeasurementComponentCompoundSystemDeflection
    from ._2673 import MountableComponentCompoundSystemDeflection
    from ._2674 import OilSealCompoundSystemDeflection
    from ._2675 import PartCompoundSystemDeflection
    from ._2676 import PartToPartShearCouplingCompoundSystemDeflection
    from ._2677 import PartToPartShearCouplingConnectionCompoundSystemDeflection
    from ._2678 import PartToPartShearCouplingHalfCompoundSystemDeflection
    from ._2679 import PlanetaryConnectionCompoundSystemDeflection
    from ._2680 import PlanetaryGearSetCompoundSystemDeflection
    from ._2681 import PlanetCarrierCompoundSystemDeflection
    from ._2682 import PointLoadCompoundSystemDeflection
    from ._2683 import PowerLoadCompoundSystemDeflection
    from ._2684 import PulleyCompoundSystemDeflection
    from ._2685 import RingPinsCompoundSystemDeflection
    from ._2686 import RingPinsToDiscConnectionCompoundSystemDeflection
    from ._2687 import RollingRingAssemblyCompoundSystemDeflection
    from ._2688 import RollingRingCompoundSystemDeflection
    from ._2689 import RollingRingConnectionCompoundSystemDeflection
    from ._2690 import RootAssemblyCompoundSystemDeflection
    from ._2691 import ShaftCompoundSystemDeflection
    from ._2692 import ShaftDutyCycleSystemDeflection
    from ._2693 import ShaftHubConnectionCompoundSystemDeflection
    from ._2694 import ShaftToMountableComponentConnectionCompoundSystemDeflection
    from ._2695 import SpecialisedAssemblyCompoundSystemDeflection
    from ._2696 import SpiralBevelGearCompoundSystemDeflection
    from ._2697 import SpiralBevelGearMeshCompoundSystemDeflection
    from ._2698 import SpiralBevelGearSetCompoundSystemDeflection
    from ._2699 import SpringDamperCompoundSystemDeflection
    from ._2700 import SpringDamperConnectionCompoundSystemDeflection
    from ._2701 import SpringDamperHalfCompoundSystemDeflection
    from ._2702 import StraightBevelDiffGearCompoundSystemDeflection
    from ._2703 import StraightBevelDiffGearMeshCompoundSystemDeflection
    from ._2704 import StraightBevelDiffGearSetCompoundSystemDeflection
    from ._2705 import StraightBevelGearCompoundSystemDeflection
    from ._2706 import StraightBevelGearMeshCompoundSystemDeflection
    from ._2707 import StraightBevelGearSetCompoundSystemDeflection
    from ._2708 import StraightBevelPlanetGearCompoundSystemDeflection
    from ._2709 import StraightBevelSunGearCompoundSystemDeflection
    from ._2710 import SynchroniserCompoundSystemDeflection
    from ._2711 import SynchroniserHalfCompoundSystemDeflection
    from ._2712 import SynchroniserPartCompoundSystemDeflection
    from ._2713 import SynchroniserSleeveCompoundSystemDeflection
    from ._2714 import TorqueConverterCompoundSystemDeflection
    from ._2715 import TorqueConverterConnectionCompoundSystemDeflection
    from ._2716 import TorqueConverterPumpCompoundSystemDeflection
    from ._2717 import TorqueConverterTurbineCompoundSystemDeflection
    from ._2718 import UnbalancedMassCompoundSystemDeflection
    from ._2719 import VirtualComponentCompoundSystemDeflection
    from ._2720 import WormGearCompoundSystemDeflection
    from ._2721 import WormGearMeshCompoundSystemDeflection
    from ._2722 import WormGearSetCompoundSystemDeflection
    from ._2723 import ZerolBevelGearCompoundSystemDeflection
    from ._2724 import ZerolBevelGearMeshCompoundSystemDeflection
    from ._2725 import ZerolBevelGearSetCompoundSystemDeflection
