"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2236 import ConcentricOrParallelPartGroup
    from ._2237 import ConcentricPartGroup
    from ._2238 import ConcentricPartGroupParallelToThis
    from ._2239 import DesignMeasurements
    from ._2240 import ParallelPartGroup
    from ._2241 import PartGroup
