"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6267 import AbstractAssemblyCriticalSpeedAnalysis
    from ._6268 import AbstractShaftCriticalSpeedAnalysis
    from ._6269 import AbstractShaftOrHousingCriticalSpeedAnalysis
    from ._6270 import AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis
    from ._6271 import AGMAGleasonConicalGearCriticalSpeedAnalysis
    from ._6272 import AGMAGleasonConicalGearMeshCriticalSpeedAnalysis
    from ._6273 import AGMAGleasonConicalGearSetCriticalSpeedAnalysis
    from ._6274 import AssemblyCriticalSpeedAnalysis
    from ._6275 import BearingCriticalSpeedAnalysis
    from ._6276 import BeltConnectionCriticalSpeedAnalysis
    from ._6277 import BeltDriveCriticalSpeedAnalysis
    from ._6278 import BevelDifferentialGearCriticalSpeedAnalysis
    from ._6279 import BevelDifferentialGearMeshCriticalSpeedAnalysis
    from ._6280 import BevelDifferentialGearSetCriticalSpeedAnalysis
    from ._6281 import BevelDifferentialPlanetGearCriticalSpeedAnalysis
    from ._6282 import BevelDifferentialSunGearCriticalSpeedAnalysis
    from ._6283 import BevelGearCriticalSpeedAnalysis
    from ._6284 import BevelGearMeshCriticalSpeedAnalysis
    from ._6285 import BevelGearSetCriticalSpeedAnalysis
    from ._6286 import BoltCriticalSpeedAnalysis
    from ._6287 import BoltedJointCriticalSpeedAnalysis
    from ._6288 import ClutchConnectionCriticalSpeedAnalysis
    from ._6289 import ClutchCriticalSpeedAnalysis
    from ._6290 import ClutchHalfCriticalSpeedAnalysis
    from ._6291 import CoaxialConnectionCriticalSpeedAnalysis
    from ._6292 import ComponentCriticalSpeedAnalysis
    from ._6293 import ConceptCouplingConnectionCriticalSpeedAnalysis
    from ._6294 import ConceptCouplingCriticalSpeedAnalysis
    from ._6295 import ConceptCouplingHalfCriticalSpeedAnalysis
    from ._6296 import ConceptGearCriticalSpeedAnalysis
    from ._6297 import ConceptGearMeshCriticalSpeedAnalysis
    from ._6298 import ConceptGearSetCriticalSpeedAnalysis
    from ._6299 import ConicalGearCriticalSpeedAnalysis
    from ._6300 import ConicalGearMeshCriticalSpeedAnalysis
    from ._6301 import ConicalGearSetCriticalSpeedAnalysis
    from ._6302 import ConnectionCriticalSpeedAnalysis
    from ._6303 import ConnectorCriticalSpeedAnalysis
    from ._6304 import CouplingConnectionCriticalSpeedAnalysis
    from ._6305 import CouplingCriticalSpeedAnalysis
    from ._6306 import CouplingHalfCriticalSpeedAnalysis
    from ._2374 import CriticalSpeedAnalysis
    from ._6307 import CriticalSpeedAnalysisDrawStyle
    from ._6308 import CriticalSpeedAnalysisOptions
    from ._6309 import CVTBeltConnectionCriticalSpeedAnalysis
    from ._6310 import CVTCriticalSpeedAnalysis
    from ._6311 import CVTPulleyCriticalSpeedAnalysis
    from ._6312 import CycloidalAssemblyCriticalSpeedAnalysis
    from ._6313 import CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis
    from ._6314 import CycloidalDiscCriticalSpeedAnalysis
    from ._6315 import CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis
    from ._6316 import CylindricalGearCriticalSpeedAnalysis
    from ._6317 import CylindricalGearMeshCriticalSpeedAnalysis
    from ._6318 import CylindricalGearSetCriticalSpeedAnalysis
    from ._6319 import CylindricalPlanetGearCriticalSpeedAnalysis
    from ._6320 import DatumCriticalSpeedAnalysis
    from ._6321 import ExternalCADModelCriticalSpeedAnalysis
    from ._6322 import FaceGearCriticalSpeedAnalysis
    from ._6323 import FaceGearMeshCriticalSpeedAnalysis
    from ._6324 import FaceGearSetCriticalSpeedAnalysis
    from ._6325 import FEPartCriticalSpeedAnalysis
    from ._6326 import FlexiblePinAssemblyCriticalSpeedAnalysis
    from ._6327 import GearCriticalSpeedAnalysis
    from ._6328 import GearMeshCriticalSpeedAnalysis
    from ._6329 import GearSetCriticalSpeedAnalysis
    from ._6330 import GuideDxfModelCriticalSpeedAnalysis
    from ._6331 import HypoidGearCriticalSpeedAnalysis
    from ._6332 import HypoidGearMeshCriticalSpeedAnalysis
    from ._6333 import HypoidGearSetCriticalSpeedAnalysis
    from ._6334 import InterMountableComponentConnectionCriticalSpeedAnalysis
    from ._6335 import KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis
    from ._6336 import KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis
    from ._6337 import KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis
    from ._6338 import KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis
    from ._6339 import KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis
    from ._6340 import KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis
    from ._6341 import KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis
    from ._6342 import KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis
    from ._6343 import KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis
    from ._6344 import MassDiscCriticalSpeedAnalysis
    from ._6345 import MeasurementComponentCriticalSpeedAnalysis
    from ._6346 import MountableComponentCriticalSpeedAnalysis
    from ._6347 import OilSealCriticalSpeedAnalysis
    from ._6348 import PartCriticalSpeedAnalysis
    from ._6349 import PartToPartShearCouplingConnectionCriticalSpeedAnalysis
    from ._6350 import PartToPartShearCouplingCriticalSpeedAnalysis
    from ._6351 import PartToPartShearCouplingHalfCriticalSpeedAnalysis
    from ._6352 import PlanetaryConnectionCriticalSpeedAnalysis
    from ._6353 import PlanetaryGearSetCriticalSpeedAnalysis
    from ._6354 import PlanetCarrierCriticalSpeedAnalysis
    from ._6355 import PointLoadCriticalSpeedAnalysis
    from ._6356 import PowerLoadCriticalSpeedAnalysis
    from ._6357 import PulleyCriticalSpeedAnalysis
    from ._6358 import RingPinsCriticalSpeedAnalysis
    from ._6359 import RingPinsToDiscConnectionCriticalSpeedAnalysis
    from ._6360 import RollingRingAssemblyCriticalSpeedAnalysis
    from ._6361 import RollingRingConnectionCriticalSpeedAnalysis
    from ._6362 import RollingRingCriticalSpeedAnalysis
    from ._6363 import RootAssemblyCriticalSpeedAnalysis
    from ._6364 import ShaftCriticalSpeedAnalysis
    from ._6365 import ShaftHubConnectionCriticalSpeedAnalysis
    from ._6366 import ShaftToMountableComponentConnectionCriticalSpeedAnalysis
    from ._6367 import SpecialisedAssemblyCriticalSpeedAnalysis
    from ._6368 import SpiralBevelGearCriticalSpeedAnalysis
    from ._6369 import SpiralBevelGearMeshCriticalSpeedAnalysis
    from ._6370 import SpiralBevelGearSetCriticalSpeedAnalysis
    from ._6371 import SpringDamperConnectionCriticalSpeedAnalysis
    from ._6372 import SpringDamperCriticalSpeedAnalysis
    from ._6373 import SpringDamperHalfCriticalSpeedAnalysis
    from ._6374 import StraightBevelDiffGearCriticalSpeedAnalysis
    from ._6375 import StraightBevelDiffGearMeshCriticalSpeedAnalysis
    from ._6376 import StraightBevelDiffGearSetCriticalSpeedAnalysis
    from ._6377 import StraightBevelGearCriticalSpeedAnalysis
    from ._6378 import StraightBevelGearMeshCriticalSpeedAnalysis
    from ._6379 import StraightBevelGearSetCriticalSpeedAnalysis
    from ._6380 import StraightBevelPlanetGearCriticalSpeedAnalysis
    from ._6381 import StraightBevelSunGearCriticalSpeedAnalysis
    from ._6382 import SynchroniserCriticalSpeedAnalysis
    from ._6383 import SynchroniserHalfCriticalSpeedAnalysis
    from ._6384 import SynchroniserPartCriticalSpeedAnalysis
    from ._6385 import SynchroniserSleeveCriticalSpeedAnalysis
    from ._6386 import TorqueConverterConnectionCriticalSpeedAnalysis
    from ._6387 import TorqueConverterCriticalSpeedAnalysis
    from ._6388 import TorqueConverterPumpCriticalSpeedAnalysis
    from ._6389 import TorqueConverterTurbineCriticalSpeedAnalysis
    from ._6390 import UnbalancedMassCriticalSpeedAnalysis
    from ._6391 import VirtualComponentCriticalSpeedAnalysis
    from ._6392 import WormGearCriticalSpeedAnalysis
    from ._6393 import WormGearMeshCriticalSpeedAnalysis
    from ._6394 import WormGearSetCriticalSpeedAnalysis
    from ._6395 import ZerolBevelGearCriticalSpeedAnalysis
    from ._6396 import ZerolBevelGearMeshCriticalSpeedAnalysis
    from ._6397 import ZerolBevelGearSetCriticalSpeedAnalysis
