"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._961 import AddendumModificationDistributionRule
    from ._962 import BacklashSpecification
    from ._963 import BasicRackProfiles
    from ._964 import CaseHardeningProperties
    from ._965 import CreateNewSuitableCutterOption
    from ._966 import CrossedAxisCylindricalGearPair
    from ._967 import CrossedAxisCylindricalGearPairLineContact
    from ._968 import CrossedAxisCylindricalGearPairPointContact
    from ._969 import CylindricalGearAbstractRack
    from ._970 import CylindricalGearAbstractRackFlank
    from ._971 import CylindricalGearBasicRack
    from ._972 import CylindricalGearBasicRackFlank
    from ._973 import CylindricalGearCuttingOptions
    from ._974 import CylindricalGearDefaults
    from ._975 import CylindricalGearDesign
    from ._976 import CylindricalGearDesignConstraint
    from ._977 import CylindricalGearDesignConstraints
    from ._978 import CylindricalGearDesignConstraintsDatabase
    from ._979 import CylindricalGearDesignConstraintSettings
    from ._980 import CylindricalGearDesignSettings
    from ._981 import CylindricalGearFlankDesign
    from ._982 import CylindricalGearMeshDesign
    from ._983 import CylindricalGearMeshFlankDesign
    from ._984 import CylindricalGearMicroGeometrySettings
    from ._985 import CylindricalGearPinionTypeCutter
    from ._986 import CylindricalGearPinionTypeCutterFlank
    from ._987 import CylindricalGearProfileMeasurement
    from ._988 import CylindricalGearProfileMeasurementType
    from ._989 import CylindricalGearProfileModifications
    from ._990 import CylindricalGearSetDesign
    from ._991 import CylindricalGearSetFlankDesign
    from ._992 import CylindricalGearSetMacroGeometryOptimiser
    from ._993 import CylindricalGearSetManufacturingConfigurationSelection
    from ._994 import CylindricalGearTableMGItemDetail
    from ._995 import CylindricalGearTableWithMGCharts
    from ._996 import CylindricalGearToothThicknessSpecification
    from ._997 import CylindricalMeshAngularBacklash
    from ._998 import CylindricalMeshedGear
    from ._999 import CylindricalMeshedGearFlank
    from ._1000 import CylindricalMeshLinearBacklashSpecification
    from ._1001 import CylindricalPlanetaryGearSetDesign
    from ._1002 import CylindricalPlanetGearDesign
    from ._1003 import DIN3967AllowanceSeries
    from ._1004 import DIN3967ToleranceSeries
    from ._1005 import DoubleAxisScaleAndRange
    from ._1006 import FinishStockSpecification
    from ._1007 import FinishToothThicknessDesignSpecification
    from ._1008 import GearFitSystems
    from ._1009 import GearManufacturingConfigSetupViewModel
    from ._1010 import GearSetManufacturingConfigurationSetup
    from ._1011 import GeometrySpecificationType
    from ._1012 import HardenedMaterialProperties
    from ._1013 import HardnessProfileCalculationMethod
    from ._1014 import HeatTreatmentType
    from ._1015 import ISO6336Geometry
    from ._1016 import ISO6336GeometryBase
    from ._1017 import ISO6336GeometryForShapedGears
    from ._1018 import ISO6336GeometryManufactured
    from ._1019 import LinearBacklashSepcification
    from ._1020 import LTCALoadCaseModifiableSettings
    from ._1021 import LtcaSettings
    from ._1022 import MicroGeometryConvention
    from ._1023 import MicroGeometryProfileConvention
    from ._1024 import Micropitting
    from ._1025 import NamedPlanetAssemblyIndex
    from ._1026 import NamedPlanetSideBandAmplitudeFactor
    from ._1027 import ReadonlyToothThicknessSpecification
    from ._1028 import RelativeMeasurementViewModel
    from ._1029 import RelativeValuesSpecification
    from ._1030 import RootStressSurfaceChartOption
    from ._1031 import Scuffing
    from ._1032 import ScuffingCoefficientOfFrictionMethods
    from ._1033 import ScuffingTemperatureMethodsAGMA
    from ._1034 import ScuffingTemperatureMethodsISO
    from ._1035 import ShaperEdgeTypes
    from ._1036 import SpurGearLoadSharingCodes
    from ._1037 import StandardRack
    from ._1038 import StandardRackFlank
    from ._1039 import SurfaceRoughness
    from ._1040 import ThicknessType
    from ._1041 import TiffAnalysisSettings
    from ._1042 import TipAlterationCoefficientMethod
    from ._1043 import TolerancedMetalMeasurements
    from ._1044 import TolerancedValueSpecification
    from ._1045 import ToothFlankFractureAnalysisSettings
    from ._1046 import ToothThicknessSpecification
    from ._1047 import ToothThicknessSpecificationBase
    from ._1048 import TypeOfMechanismHousing
    from ._1049 import Usage
