"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3907 import AbstractAssemblyCompoundPowerFlow
    from ._3908 import AbstractShaftCompoundPowerFlow
    from ._3909 import AbstractShaftOrHousingCompoundPowerFlow
    from ._3910 import AbstractShaftToMountableComponentConnectionCompoundPowerFlow
    from ._3911 import AGMAGleasonConicalGearCompoundPowerFlow
    from ._3912 import AGMAGleasonConicalGearMeshCompoundPowerFlow
    from ._3913 import AGMAGleasonConicalGearSetCompoundPowerFlow
    from ._3914 import AssemblyCompoundPowerFlow
    from ._3915 import BearingCompoundPowerFlow
    from ._3916 import BeltConnectionCompoundPowerFlow
    from ._3917 import BeltDriveCompoundPowerFlow
    from ._3918 import BevelDifferentialGearCompoundPowerFlow
    from ._3919 import BevelDifferentialGearMeshCompoundPowerFlow
    from ._3920 import BevelDifferentialGearSetCompoundPowerFlow
    from ._3921 import BevelDifferentialPlanetGearCompoundPowerFlow
    from ._3922 import BevelDifferentialSunGearCompoundPowerFlow
    from ._3923 import BevelGearCompoundPowerFlow
    from ._3924 import BevelGearMeshCompoundPowerFlow
    from ._3925 import BevelGearSetCompoundPowerFlow
    from ._3926 import BoltCompoundPowerFlow
    from ._3927 import BoltedJointCompoundPowerFlow
    from ._3928 import ClutchCompoundPowerFlow
    from ._3929 import ClutchConnectionCompoundPowerFlow
    from ._3930 import ClutchHalfCompoundPowerFlow
    from ._3931 import CoaxialConnectionCompoundPowerFlow
    from ._3932 import ComponentCompoundPowerFlow
    from ._3933 import ConceptCouplingCompoundPowerFlow
    from ._3934 import ConceptCouplingConnectionCompoundPowerFlow
    from ._3935 import ConceptCouplingHalfCompoundPowerFlow
    from ._3936 import ConceptGearCompoundPowerFlow
    from ._3937 import ConceptGearMeshCompoundPowerFlow
    from ._3938 import ConceptGearSetCompoundPowerFlow
    from ._3939 import ConicalGearCompoundPowerFlow
    from ._3940 import ConicalGearMeshCompoundPowerFlow
    from ._3941 import ConicalGearSetCompoundPowerFlow
    from ._3942 import ConnectionCompoundPowerFlow
    from ._3943 import ConnectorCompoundPowerFlow
    from ._3944 import CouplingCompoundPowerFlow
    from ._3945 import CouplingConnectionCompoundPowerFlow
    from ._3946 import CouplingHalfCompoundPowerFlow
    from ._3947 import CVTBeltConnectionCompoundPowerFlow
    from ._3948 import CVTCompoundPowerFlow
    from ._3949 import CVTPulleyCompoundPowerFlow
    from ._3950 import CycloidalAssemblyCompoundPowerFlow
    from ._3951 import CycloidalDiscCentralBearingConnectionCompoundPowerFlow
    from ._3952 import CycloidalDiscCompoundPowerFlow
    from ._3953 import CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow
    from ._3954 import CylindricalGearCompoundPowerFlow
    from ._3955 import CylindricalGearMeshCompoundPowerFlow
    from ._3956 import CylindricalGearSetCompoundPowerFlow
    from ._3957 import CylindricalPlanetGearCompoundPowerFlow
    from ._3958 import DatumCompoundPowerFlow
    from ._3959 import ExternalCADModelCompoundPowerFlow
    from ._3960 import FaceGearCompoundPowerFlow
    from ._3961 import FaceGearMeshCompoundPowerFlow
    from ._3962 import FaceGearSetCompoundPowerFlow
    from ._3963 import FEPartCompoundPowerFlow
    from ._3964 import FlexiblePinAssemblyCompoundPowerFlow
    from ._3965 import GearCompoundPowerFlow
    from ._3966 import GearMeshCompoundPowerFlow
    from ._3967 import GearSetCompoundPowerFlow
    from ._3968 import GuideDxfModelCompoundPowerFlow
    from ._3969 import HypoidGearCompoundPowerFlow
    from ._3970 import HypoidGearMeshCompoundPowerFlow
    from ._3971 import HypoidGearSetCompoundPowerFlow
    from ._3972 import InterMountableComponentConnectionCompoundPowerFlow
    from ._3973 import KlingelnbergCycloPalloidConicalGearCompoundPowerFlow
    from ._3974 import KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow
    from ._3975 import KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow
    from ._3976 import KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow
    from ._3977 import KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow
    from ._3978 import KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow
    from ._3979 import KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow
    from ._3980 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow
    from ._3981 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow
    from ._3982 import MassDiscCompoundPowerFlow
    from ._3983 import MeasurementComponentCompoundPowerFlow
    from ._3984 import MountableComponentCompoundPowerFlow
    from ._3985 import OilSealCompoundPowerFlow
    from ._3986 import PartCompoundPowerFlow
    from ._3987 import PartToPartShearCouplingCompoundPowerFlow
    from ._3988 import PartToPartShearCouplingConnectionCompoundPowerFlow
    from ._3989 import PartToPartShearCouplingHalfCompoundPowerFlow
    from ._3990 import PlanetaryConnectionCompoundPowerFlow
    from ._3991 import PlanetaryGearSetCompoundPowerFlow
    from ._3992 import PlanetCarrierCompoundPowerFlow
    from ._3993 import PointLoadCompoundPowerFlow
    from ._3994 import PowerLoadCompoundPowerFlow
    from ._3995 import PulleyCompoundPowerFlow
    from ._3996 import RingPinsCompoundPowerFlow
    from ._3997 import RingPinsToDiscConnectionCompoundPowerFlow
    from ._3998 import RollingRingAssemblyCompoundPowerFlow
    from ._3999 import RollingRingCompoundPowerFlow
    from ._4000 import RollingRingConnectionCompoundPowerFlow
    from ._4001 import RootAssemblyCompoundPowerFlow
    from ._4002 import ShaftCompoundPowerFlow
    from ._4003 import ShaftHubConnectionCompoundPowerFlow
    from ._4004 import ShaftToMountableComponentConnectionCompoundPowerFlow
    from ._4005 import SpecialisedAssemblyCompoundPowerFlow
    from ._4006 import SpiralBevelGearCompoundPowerFlow
    from ._4007 import SpiralBevelGearMeshCompoundPowerFlow
    from ._4008 import SpiralBevelGearSetCompoundPowerFlow
    from ._4009 import SpringDamperCompoundPowerFlow
    from ._4010 import SpringDamperConnectionCompoundPowerFlow
    from ._4011 import SpringDamperHalfCompoundPowerFlow
    from ._4012 import StraightBevelDiffGearCompoundPowerFlow
    from ._4013 import StraightBevelDiffGearMeshCompoundPowerFlow
    from ._4014 import StraightBevelDiffGearSetCompoundPowerFlow
    from ._4015 import StraightBevelGearCompoundPowerFlow
    from ._4016 import StraightBevelGearMeshCompoundPowerFlow
    from ._4017 import StraightBevelGearSetCompoundPowerFlow
    from ._4018 import StraightBevelPlanetGearCompoundPowerFlow
    from ._4019 import StraightBevelSunGearCompoundPowerFlow
    from ._4020 import SynchroniserCompoundPowerFlow
    from ._4021 import SynchroniserHalfCompoundPowerFlow
    from ._4022 import SynchroniserPartCompoundPowerFlow
    from ._4023 import SynchroniserSleeveCompoundPowerFlow
    from ._4024 import TorqueConverterCompoundPowerFlow
    from ._4025 import TorqueConverterConnectionCompoundPowerFlow
    from ._4026 import TorqueConverterPumpCompoundPowerFlow
    from ._4027 import TorqueConverterTurbineCompoundPowerFlow
    from ._4028 import UnbalancedMassCompoundPowerFlow
    from ._4029 import VirtualComponentCompoundPowerFlow
    from ._4030 import WormGearCompoundPowerFlow
    from ._4031 import WormGearMeshCompoundPowerFlow
    from ._4032 import WormGearSetCompoundPowerFlow
    from ._4033 import ZerolBevelGearCompoundPowerFlow
    from ._4034 import ZerolBevelGearMeshCompoundPowerFlow
    from ._4035 import ZerolBevelGearSetCompoundPowerFlow
