"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3639 import AbstractAssemblyCompoundStabilityAnalysis
    from ._3640 import AbstractShaftCompoundStabilityAnalysis
    from ._3641 import AbstractShaftOrHousingCompoundStabilityAnalysis
    from ._3642 import AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis
    from ._3643 import AGMAGleasonConicalGearCompoundStabilityAnalysis
    from ._3644 import AGMAGleasonConicalGearMeshCompoundStabilityAnalysis
    from ._3645 import AGMAGleasonConicalGearSetCompoundStabilityAnalysis
    from ._3646 import AssemblyCompoundStabilityAnalysis
    from ._3647 import BearingCompoundStabilityAnalysis
    from ._3648 import BeltConnectionCompoundStabilityAnalysis
    from ._3649 import BeltDriveCompoundStabilityAnalysis
    from ._3650 import BevelDifferentialGearCompoundStabilityAnalysis
    from ._3651 import BevelDifferentialGearMeshCompoundStabilityAnalysis
    from ._3652 import BevelDifferentialGearSetCompoundStabilityAnalysis
    from ._3653 import BevelDifferentialPlanetGearCompoundStabilityAnalysis
    from ._3654 import BevelDifferentialSunGearCompoundStabilityAnalysis
    from ._3655 import BevelGearCompoundStabilityAnalysis
    from ._3656 import BevelGearMeshCompoundStabilityAnalysis
    from ._3657 import BevelGearSetCompoundStabilityAnalysis
    from ._3658 import BoltCompoundStabilityAnalysis
    from ._3659 import BoltedJointCompoundStabilityAnalysis
    from ._3660 import ClutchCompoundStabilityAnalysis
    from ._3661 import ClutchConnectionCompoundStabilityAnalysis
    from ._3662 import ClutchHalfCompoundStabilityAnalysis
    from ._3663 import CoaxialConnectionCompoundStabilityAnalysis
    from ._3664 import ComponentCompoundStabilityAnalysis
    from ._3665 import ConceptCouplingCompoundStabilityAnalysis
    from ._3666 import ConceptCouplingConnectionCompoundStabilityAnalysis
    from ._3667 import ConceptCouplingHalfCompoundStabilityAnalysis
    from ._3668 import ConceptGearCompoundStabilityAnalysis
    from ._3669 import ConceptGearMeshCompoundStabilityAnalysis
    from ._3670 import ConceptGearSetCompoundStabilityAnalysis
    from ._3671 import ConicalGearCompoundStabilityAnalysis
    from ._3672 import ConicalGearMeshCompoundStabilityAnalysis
    from ._3673 import ConicalGearSetCompoundStabilityAnalysis
    from ._3674 import ConnectionCompoundStabilityAnalysis
    from ._3675 import ConnectorCompoundStabilityAnalysis
    from ._3676 import CouplingCompoundStabilityAnalysis
    from ._3677 import CouplingConnectionCompoundStabilityAnalysis
    from ._3678 import CouplingHalfCompoundStabilityAnalysis
    from ._3679 import CVTBeltConnectionCompoundStabilityAnalysis
    from ._3680 import CVTCompoundStabilityAnalysis
    from ._3681 import CVTPulleyCompoundStabilityAnalysis
    from ._3682 import CycloidalAssemblyCompoundStabilityAnalysis
    from ._3683 import CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis
    from ._3684 import CycloidalDiscCompoundStabilityAnalysis
    from ._3685 import CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis
    from ._3686 import CylindricalGearCompoundStabilityAnalysis
    from ._3687 import CylindricalGearMeshCompoundStabilityAnalysis
    from ._3688 import CylindricalGearSetCompoundStabilityAnalysis
    from ._3689 import CylindricalPlanetGearCompoundStabilityAnalysis
    from ._3690 import DatumCompoundStabilityAnalysis
    from ._3691 import ExternalCADModelCompoundStabilityAnalysis
    from ._3692 import FaceGearCompoundStabilityAnalysis
    from ._3693 import FaceGearMeshCompoundStabilityAnalysis
    from ._3694 import FaceGearSetCompoundStabilityAnalysis
    from ._3695 import FEPartCompoundStabilityAnalysis
    from ._3696 import FlexiblePinAssemblyCompoundStabilityAnalysis
    from ._3697 import GearCompoundStabilityAnalysis
    from ._3698 import GearMeshCompoundStabilityAnalysis
    from ._3699 import GearSetCompoundStabilityAnalysis
    from ._3700 import GuideDxfModelCompoundStabilityAnalysis
    from ._3701 import HypoidGearCompoundStabilityAnalysis
    from ._3702 import HypoidGearMeshCompoundStabilityAnalysis
    from ._3703 import HypoidGearSetCompoundStabilityAnalysis
    from ._3704 import InterMountableComponentConnectionCompoundStabilityAnalysis
    from ._3705 import KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis
    from ._3706 import KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis
    from ._3707 import KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis
    from ._3708 import KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis
    from ._3709 import KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis
    from ._3710 import KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis
    from ._3711 import KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis
    from ._3712 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis
    from ._3713 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis
    from ._3714 import MassDiscCompoundStabilityAnalysis
    from ._3715 import MeasurementComponentCompoundStabilityAnalysis
    from ._3716 import MountableComponentCompoundStabilityAnalysis
    from ._3717 import OilSealCompoundStabilityAnalysis
    from ._3718 import PartCompoundStabilityAnalysis
    from ._3719 import PartToPartShearCouplingCompoundStabilityAnalysis
    from ._3720 import PartToPartShearCouplingConnectionCompoundStabilityAnalysis
    from ._3721 import PartToPartShearCouplingHalfCompoundStabilityAnalysis
    from ._3722 import PlanetaryConnectionCompoundStabilityAnalysis
    from ._3723 import PlanetaryGearSetCompoundStabilityAnalysis
    from ._3724 import PlanetCarrierCompoundStabilityAnalysis
    from ._3725 import PointLoadCompoundStabilityAnalysis
    from ._3726 import PowerLoadCompoundStabilityAnalysis
    from ._3727 import PulleyCompoundStabilityAnalysis
    from ._3728 import RingPinsCompoundStabilityAnalysis
    from ._3729 import RingPinsToDiscConnectionCompoundStabilityAnalysis
    from ._3730 import RollingRingAssemblyCompoundStabilityAnalysis
    from ._3731 import RollingRingCompoundStabilityAnalysis
    from ._3732 import RollingRingConnectionCompoundStabilityAnalysis
    from ._3733 import RootAssemblyCompoundStabilityAnalysis
    from ._3734 import ShaftCompoundStabilityAnalysis
    from ._3735 import ShaftHubConnectionCompoundStabilityAnalysis
    from ._3736 import ShaftToMountableComponentConnectionCompoundStabilityAnalysis
    from ._3737 import SpecialisedAssemblyCompoundStabilityAnalysis
    from ._3738 import SpiralBevelGearCompoundStabilityAnalysis
    from ._3739 import SpiralBevelGearMeshCompoundStabilityAnalysis
    from ._3740 import SpiralBevelGearSetCompoundStabilityAnalysis
    from ._3741 import SpringDamperCompoundStabilityAnalysis
    from ._3742 import SpringDamperConnectionCompoundStabilityAnalysis
    from ._3743 import SpringDamperHalfCompoundStabilityAnalysis
    from ._3744 import StraightBevelDiffGearCompoundStabilityAnalysis
    from ._3745 import StraightBevelDiffGearMeshCompoundStabilityAnalysis
    from ._3746 import StraightBevelDiffGearSetCompoundStabilityAnalysis
    from ._3747 import StraightBevelGearCompoundStabilityAnalysis
    from ._3748 import StraightBevelGearMeshCompoundStabilityAnalysis
    from ._3749 import StraightBevelGearSetCompoundStabilityAnalysis
    from ._3750 import StraightBevelPlanetGearCompoundStabilityAnalysis
    from ._3751 import StraightBevelSunGearCompoundStabilityAnalysis
    from ._3752 import SynchroniserCompoundStabilityAnalysis
    from ._3753 import SynchroniserHalfCompoundStabilityAnalysis
    from ._3754 import SynchroniserPartCompoundStabilityAnalysis
    from ._3755 import SynchroniserSleeveCompoundStabilityAnalysis
    from ._3756 import TorqueConverterCompoundStabilityAnalysis
    from ._3757 import TorqueConverterConnectionCompoundStabilityAnalysis
    from ._3758 import TorqueConverterPumpCompoundStabilityAnalysis
    from ._3759 import TorqueConverterTurbineCompoundStabilityAnalysis
    from ._3760 import UnbalancedMassCompoundStabilityAnalysis
    from ._3761 import VirtualComponentCompoundStabilityAnalysis
    from ._3762 import WormGearCompoundStabilityAnalysis
    from ._3763 import WormGearMeshCompoundStabilityAnalysis
    from ._3764 import WormGearSetCompoundStabilityAnalysis
    from ._3765 import ZerolBevelGearCompoundStabilityAnalysis
    from ._3766 import ZerolBevelGearMeshCompoundStabilityAnalysis
    from ._3767 import ZerolBevelGearSetCompoundStabilityAnalysis
