"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._948 import HypoidGearDesign
    from ._949 import HypoidGearMeshDesign
    from ._950 import HypoidGearSetDesign
    from ._951 import HypoidMeshedGearDesign
