"""_1279.py

BoltShankType
"""


from enum import Enum

from mastapy._internal.python_net import python_net_import

_BOLT_SHANK_TYPE = python_net_import('SMT.MastaAPI.Bolts', 'BoltShankType')


__docformat__ = 'restructuredtext en'
__all__ = ('BoltShankType',)


class BoltShankType(Enum):
    """BoltShankType

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _BOLT_SHANK_TYPE

    __hash__ = None

    SHANKED = 0
    NECKED_DOWN = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


BoltShankType.__setattr__ = __enum_setattr
BoltShankType.__delattr__ = __enum_delattr
