"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._952 import FaceGearDesign
    from ._953 import FaceGearDiameterFaceWidthSpecificationMethod
    from ._954 import FaceGearMeshDesign
    from ._955 import FaceGearMeshMicroGeometry
    from ._956 import FaceGearMicroGeometry
    from ._957 import FaceGearPinionDesign
    from ._958 import FaceGearSetDesign
    from ._959 import FaceGearSetMicroGeometry
    from ._960 import FaceGearWheelDesign
